==> tdm_2.1.1.tar.gz: tdm/R/all.Amianhirms.R <==
all.Amianhirms<-function(){
     cat("\n")                                                                       
     cat("--------------------------------------------------------------\n")
     cat("    --Aminophylline anhydrous IR input data information--     \n")
     note_for_Theirss_input()
     cat("--------------------------------------------------------------\n")
     cat("\n")
     note_for_close_window()
     AmianhirMSpar<-data.frame(subject=c(1,2),Gender=c(0),age=c(0),ht=c(0),CHF=c(0),smoke=c(0),D=c(0),tau=c(0),ts=c(0),c=c(0))
     AmianhirMSpar<-edit(AmianhirMSpar)
     AmianhirMSpar<-ymscheck(AmianhirMSpar)
     cat("\n")
     Amianhir.ms(length(AmianhirMSpar$subject),AmianhirMSpar$c,AmianhirMSpar$tau,AmianhirMSpar$ts,AmianhirMSpar$D,AmianhirMSpar$ht,AmianhirMSpar$age,AmianhirMSpar$smoke,AmianhirMSpar$Gender,AmianhirMSpar$CHF)   # calculate individual aminophylline anhydrous PK parameters and show its prediction
     note_for_convergence_plots()
     note_for_plot()
     convergence_plots_con()
     cat("\n\n")
     cat("------------------------------------------------------------------\n")
     cat("    --Aminophylline anhydrous IR output data information--        \n")
     note_for_Theirss_output()
     cat("------------------------------------------------------------------\n")
     show(samplesStats("*"))
     cat("\n")
     C<-TheIRsscpr(0.85,AmianhirMSpar$D,AmianhirMSpar$tau,AmianhirMSpar$ts)
     sim<-matrix(C[ ,1])                                                      # [ ,1]
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Cmss_pr (mg/L)")
     output1<-coutput
     show(coutput)
     r=log(1.85-(samplesStats("cl_F")/samplesStats("v_F")))/(1.85-(samplesStats("cl_F")/samplesStats("v_F")))
     C<-TheIRsscpr(0.85,AmianhirMSpar$D,AmianhirMSpar$tau,r)
     sim<-matrix(C[ ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Cpss_pr (mg/L)")
     output2<-coutput
     show(coutput)
     C<-TheIRsscpr(0.85,AmianhirMSpar$D,AmianhirMSpar$tau,AmianhirMSpar$tau)
     sim<-matrix(C[ ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Ctss_pr (mg/L)")
     output3<-coutput
     show(coutput)     
     cat("\n") 
     cal.again()  
}

==> tdm_2.2.2.tar.gz: tdm/R/all.Amianhirms.R <==
all.Amianhirms<-function(){
     cat("\n")                                                                       
     cat("--------------------------------------------------------------\n")
     cat("    --Aminophylline anhydrous IR input data information--     \n")
     note_for_Theirss_input()
     cat("--------------------------------------------------------------\n")
     cat("\n")
     note_for_close_window()
     AmianhirMSpar<-data.frame(subject=c(1,2),Gender=c(0),age=c(0),ht=c(0),CHF=c(0),smoke=c(0),D=c(0),tau=c(0),ts=c(0),c=c(0))
     AmianhirMSpar<-edit(AmianhirMSpar)
##     AmianhirMSpar<-ymscheck(AmianhirMSpar)
     cat("\n")
     Amianhir.ms(length(AmianhirMSpar$subject),AmianhirMSpar$c,AmianhirMSpar$tau,AmianhirMSpar$ts,AmianhirMSpar$D,AmianhirMSpar$ht,AmianhirMSpar$age,AmianhirMSpar$smoke,AmianhirMSpar$Gender,AmianhirMSpar$CHF)   # calculate individual aminophylline anhydrous PK parameters and show its prediction
     note_for_convergence_plots()
     note_for_plot()
     convergence_plots_con()
     cat("\n\n")
     cat("------------------------------------------------------------------\n")
     cat("    --Aminophylline anhydrous IR output data information--        \n")
     note_for_Theirss_output()
     cat("------------------------------------------------------------------\n")
     show(samplesStats("*"))
     cat("\n")
     C<-TheIRsscpr(0.85,AmianhirMSpar$D,AmianhirMSpar$tau,AmianhirMSpar$ts)
     sim<-matrix(C[ ,1])                                                      # [ ,1]
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Cmss_pr (mg/L)")
     output1<-coutput
     show(coutput)
     r=log(1.85-(samplesStats("cl_F")/samplesStats("v_F")))/(1.85-(samplesStats("cl_F")/samplesStats("v_F")))
     C<-TheIRsscpr(0.85,AmianhirMSpar$D,AmianhirMSpar$tau,r)
     sim<-matrix(C[ ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Cpss_pr (mg/L)")
     output2<-coutput
     show(coutput)
     C<-TheIRsscpr(0.85,AmianhirMSpar$D,AmianhirMSpar$tau,AmianhirMSpar$tau)
     sim<-matrix(C[ ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Ctss_pr (mg/L)")
     output3<-coutput
     show(coutput)     
     cat("\n") 
     cal.again()  
}
